==> apache-tez-0.7.0-src.tar.gz: apache-tez-0.7.0-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskEventScheduleTask.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.tez.dag.api.TaskLocationHint;
import org.apache.tez.dag.records.TezTaskID;
import org.apache.tez.runtime.api.impl.TaskSpec;

public class TaskEventScheduleTask extends TaskEvent {
  private final TaskSpec baseTaskSpec;
  private final TaskLocationHint locationHint;
  
  public TaskEventScheduleTask(TezTaskID taskId, TaskSpec baseTaskSpec, TaskLocationHint locationHint) {
    super(taskId, TaskEventType.T_SCHEDULE);
    this.baseTaskSpec = baseTaskSpec;
    this.locationHint = locationHint;
  }
  
  public TaskSpec getBaseTaskSpec() {
    return baseTaskSpec;
  }
  
  public TaskLocationHint getTaskLocationHint() {
    return locationHint;
  }
}

==> apache-tez-0.10.0-src.tar.gz: apache-tez-0.10.0-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskEventScheduleTask.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.tez.dag.api.TaskLocationHint;
import org.apache.tez.dag.records.TezTaskID;
import org.apache.tez.runtime.api.impl.TaskSpec;

public class TaskEventScheduleTask extends TaskEvent implements RecoveryEvent {
  private final TaskSpec baseTaskSpec;
  private final TaskLocationHint locationHint;
  private final boolean fromRecovery;

  public TaskEventScheduleTask(TezTaskID taskId, TaskSpec baseTaskSpec, TaskLocationHint locationHint,
      boolean fromRecovery) {
    super(taskId, TaskEventType.T_SCHEDULE);
    this.baseTaskSpec = baseTaskSpec;
    this.locationHint = locationHint;
    this.fromRecovery = fromRecovery;
  }
  
  public TaskSpec getBaseTaskSpec() {
    return baseTaskSpec;
  }
  
  public TaskLocationHint getTaskLocationHint() {
    return locationHint;
  }

  @Override
  public boolean isFromRecovery() {
    return fromRecovery;
  }
}
